summaryrefslogtreecommitdiffstats
path: root/wp-includes/html-api/class-wp-html-span.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-includes/html-api/class-wp-html-span.php')
-rw-r--r--wp-includes/html-api/class-wp-html-span.php19
1 files changed, 11 insertions, 8 deletions
diff --git a/wp-includes/html-api/class-wp-html-span.php b/wp-includes/html-api/class-wp-html-span.php
index 46227eb..b1ab865 100644
--- a/wp-includes/html-api/class-wp-html-span.php
+++ b/wp-includes/html-api/class-wp-html-span.php
@@ -18,6 +18,7 @@
*
* @access private
* @since 6.2.0
+ * @since 6.5.0 Replaced `end` with `length` to more closely align with `substr()`.
*
* @see WP_HTML_Tag_Processor
*/
@@ -26,28 +27,30 @@ class WP_HTML_Span {
* Byte offset into document where span begins.
*
* @since 6.2.0
+ *
* @var int
*/
public $start;
/**
- * Byte offset into document where span ends.
+ * Byte length of this span.
+ *
+ * @since 6.5.0
*
- * @since 6.2.0
* @var int
*/
- public $end;
+ public $length;
/**
* Constructor.
*
* @since 6.2.0
*
* @param int $start Byte offset into document where replacement span begins.
* @param int $end Byte offset into document where replacement span ends.
*/
- public function __construct( $start, $end ) {
- $this->start = $start;
- $this->end = $end;
+ public function __construct( $start, $length ) {
+ $this->start = $start;
+ $this->length = $length;
}
}
@@ -26,28 +27,30 @@ class WP_HTML_Span {
* @since 6.2.0
*
- * @param int $start Byte offset into document where replacement span begins.
- * @param int $end Byte offset into document where replacement span ends.
+ * @param int $start Byte offset into document where replacement span begins.
+ * @param int $length Byte length of span.
*/